@@ -1,4 +1,4 @@
-use clap::{builder::PossibleValue, ValueEnum};
+use clap::{ValueEnum, builder::PossibleValue};
 use nu_ansi_term::AnsiStrings;
 use rayon::prelude::*;
 use std::collections::BTreeSet;
@@ -13,15 +13,16 @@ use unicode_width::UnicodeWidthChar;
 use crate::configs::PROMPT_ORDER;
 use crate::context::{Context, Properties, Shell, Target};
 use crate::formatter::{StringFormatter, VariableHolder};
-use crate::module::Module;
 use crate::module::ALL_MODULES;
+use crate::module::Module;
 use crate::modules;
 use crate::segment::Segment;
 use crate::shadow;
+use crate::utils::wrap_colorseq_for_shell;
 
 pub struct Grapheme<'a>(pub &'a str);
 
-impl<'a> Grapheme<'a> {
+impl Grapheme<'_> {
     pub fn width(&self) -> usize {
         self.0
             .chars()
@@ -115,12 +116,16 @@ pub fn get_prompt(context: Context) -> String {
             .expect("Unexpected error returned in root format variables"),
     );
 
-    let module_strings = root_module.ansi_strings_for_shell(context.shell, Some(context.width));
+    let module_strings = root_module.ansi_strings_for_width(Some(context.width));
     if config.add_newline && context.target != Target::Continuation {
         // continuation prompts normally do not include newlines, but they can
         writeln!(buf).unwrap();
     }
-    write!(buf, "{}", AnsiStrings(&module_strings)).unwrap();
+    // AnsiStrings strips redundant ANSI color sequences, so apply it before modifying the ANSI
+    // color sequences for this specific shell
+    let shell_wrapped_output =
+        wrap_colorseq_for_shell(AnsiStrings(&module_strings).to_string(), context.shell);
+    write!(buf, "{shell_wrapped_output}").unwrap();
 
     if context.target == Target::Right {
         // right prompts generally do not allow newlines
@@ -649,7 +654,7 @@ mod test {
         preset_command(Some(Preset("nerd-font-symbols")), Some(path.clone()), false);
 
         let actual = utils::read_file(&path)?;
-        let expected = include_str!("../docs/.vuepress/public/presets/toml/nerd-font-symbols.toml");
+        let expected = include_str!("../docs/public/presets/toml/nerd-font-symbols.toml");
         assert_eq!(actual, expected);
 
         dir.close()
